clear;

% display results

SET = 1 % experiment number

DATAPATH = './';

% ---------------------------------------------------------------------------
% load data
sname = sprintf('%sResults_V6_%d.mat',DATAPATH,SET);
load(sname,'KeyResult')
  
fig1 = figure;
set(fig1,'Position',[  196         456        1775         462]);
set(fig1,'Name',sprintf('DataSet %d',SET))


%--------------------------------------------------------------------------------
% group-level means of templates with bootstrap CIs
%--------------------------------------------------------------------------------
subplot(2,4,1); hold on

h = fill([KeyResult.time_ax(1:end) KeyResult.time_ax(end:-1:1)],[KeyResult.PercepWeight_CI(1,:) KeyResult.PercepWeight_CI(2,[end:-1:1])],[0.6 0.6 0.6]);
set(h,'EdgeColor',[0.6 0.6 0.6])
h = plot(KeyResult.time_ax,mean(KeyResult.PercepWeight));
set(h,'LineWidth',2,'Color','k')
xlabel('time [s]'); ylabel('[Z-value]');
title('Psychophysical weights');
a = axis;
axis([0 KeyResult.time_ax(end) a(3) a(4)])
set(gca,'XTick',[0:0.2:1.8]);


%--------------------------------------------------------------------------------
% - Power spectrum with group-level CI 
% - Peak of group-level spectrum
%--------------------------------------------------------------------------------
subplot(2,4,2); hold on;

h = fill([KeyResult.Spectrum.fax(1:end) KeyResult.Spectrum.fax(end:-1:1)],[KeyResult.Spectrum.power_CI(1,:) KeyResult.Spectrum.power_CI(2,[end:-1:1])],[0.6 0.6 0.6]);
set(h,'EdgeColor',[0.6 0.6 0.6])
h = plot(KeyResult.Spectrum.fax,mean(KeyResult.Spectrum.power));
set(h,'LineWidth',2,'Color','k')
title(['Freq. Spectrum'])
xlabel('Frequency [Hz]'); ylabel('[dB]');
axis([0 max(KeyResult.ARG.flist) -4 1])
set(gca,'XTick',[0:1:8],'YTick',[-4:1:1]);
plot(KeyResult.Spectrum.fax,KeyResult.Spectrum.Rand_CI(2,:),'--','Color',ones(1,3)*0.6,'LineWidth',2);



%% --------------------------------------------------------------------------------
% Model comparison of 'trivial models'. 
% here we ask how well the templates are fit by a 
% - constant offset (should be there by design, performance around 75% correct)
% - constant + linear slope,
% - constant + slope +  a U/V shaped term adapted to the stimulus duration
% for each participant we compute the log evidence from three regression models
%--------------------------------------------------------------------------------
% subplot(2,4,3);  hold on;
% h = bar(KeyResult.trivial.EP); set(h,'FaceColor','k');
% title('Trivial models');
% ylabel('Exc. prob.')
% axis([0.5 3.5 0 1]); set(gca,'XTick',[1:3],'YTick',[0:0.2:1],'XTickLabel',{'const','lin','u/v'});




%% --------------------------------------------------------------------------------
% Model comparison of the best trivial model and rhythmic models at different frequencies
% we fit both models using 2-fold cross-validation, repeated x times
% here we need to recompute the templates for the CV loop (slow)
%--------------------------------------------------------------------------------
subplot(2,4,3);  hold on;
yyaxis left
tmp = KeyResult.Freqmod.AICcg_f(1:end);
tmp = tmp-min(tmp);
plot(KeyResult.ARG.flist,tmp(2:end),'b','LineWidth',2); 
plot(0,tmp(1),'bo','LineWidth',2); 
% add each individual participant's best frequency
plot(KeyResult.Freqmod.Bestfreq_each_AICc,20+rand(1,KeyResult.Basics.NSub)*40,'k.','MarkerSize',10)
title('AICc rhythmic models');
xlabel('Freq [Hz]'); ylabel('AICc');
axis([0 5 0 400]);
set(gca,'XTick',[0:1:5]);

%% --------------------------------------------------------------------------------
% Model comparison between  best trivial model and the best rhythmic model based on the 
% group-level frequency
%--------------------------------------------------------------------------------
subplot(2,4,4); hold on;
h = bar(KeyResult.Freqmod.AIC_EP); set(h,'FaceColor','k');
title('RFX model comparison');
ylabel('Exc. prob.')
axis([0.5 2.5 0 1]); set(gca,'XTick',[1,2],'XTickLabel',{'Triv','Rhythmic'});


%% --------------------------------------------------------------------------------
% group-level analysis based on Monte-Carlo simulations (using the Bayesian regression toolbox)
% and the WAIC weight to estimate the out-of-sample variance

subplot(2,4,3); hold on;
yyaxis right
a = sum(KeyResult.Freqmod.WAIC,1);
a = a-min(a);
plot(KeyResult.ARG.flist,a(2:end),'r','LineWidth',2)
plot(0,a(1),'ro','LineWidth',2); 
ylabel('WAIC')


%% ---------------------------------------------------------------------------
% analysis of winning models
% here we recompute the model weights without CV on the full data 
% to collect beta's and best phase  values
% best trivial model + best rhythmic model at group-level frequency
%-----------------------------------------------------------------------------
nsub = size(KeyResult.PercepWeight,1);
subplot(2,4,5);
tmp2 = sqrt(sum((KeyResult.Freqmod.Beta_w(:,[-1,0]+end)).^2,2));
tmp = cat(2,KeyResult.Freqmod.Beta_w(:,[1:KeyResult.best_triv]),tmp2);
ckerror_bar(mean(tmp),std(tmp)./sqrt(nsub-1));
title('Beta')
set(gca,'XTick',[1:KeyResult.best_triv+1],'XTickLabel',{'off','Lin','u/v','R'});

% phase angle
subplot(2,4,7);
polarplot(exp(i*atan2(KeyResult.Freqmod.Beta_w(:,end-1),KeyResult.Freqmod.Beta_w(:,end))),'ko')

% group-level model
subplot(2,4,1); hold on
plot(KeyResult.time_ax,KeyResult.Freqmod.GroupModel,'g--');


% display each subjects rhythmic component 
subplot(2,4,6); hold on
for S=1:nsub
  plot(KeyResult.time_ax,KeyResult.Freqmod.EachModel(S,:),'k');
end
set(gca,'XTick',[0:0.2:1.8],'YTick',[-1.5 1.5]);
xlabel('time [s]'); ylabel('[Z-value]');
a = axis; a = max(abs(a(3:4)));
axis([0 KeyResult.time_ax(end) -a a]);
title('Rhythmic components ')




%---------------------------------------------------------------------------
% finish
Ch = get(fig1,'Children');

for l=1:length(Ch)
  try
    set(Ch(l),'TickLength',[0.02 0.02]);
    set(Ch(l),'Box','Off');
  catch 
  end
end
set(gcf,'PaperOrientation','Landscape')
set(gcf,'PaperOrientation','Landscape')


